@@ -32,6 +32,7 @@ from .translation_config import (
     BigQueryDialect,
     Dialect,
     HiveQLDialect,
+    MySQLDialect,
     NameMappingKey,
     NameMappingValue,
     NetezzaDialect,
@@ -74,6 +75,7 @@ __all__ = (
     "BigQueryDialect",
     "Dialect",
     "HiveQLDialect",
+    "MySQLDialect",
     "NameMappingKey",
     "NameMappingValue",
     "NetezzaDialect",
